@@ -3,8 +3,7 @@ package Foorum::TheSchwartz::Worker::ResizeProfilePhoto;
 use strict;
 use warnings;
 use Foorum::Version; our $VERSION = $Foorum::VERSION;
-use TheSchwartz::Job;
-use base qw( TheSchwartz::Worker );
+use base qw( MooseX::TheSchwartz::Worker );
 use Foorum::SUtils qw/schema/;
 use Foorum::XUtils qw/base_path/;
 use Image::Magick;
@@ -13,7 +12,7 @@ use File::Spec;
 
 sub work {
     my $class = shift;
-    my TheSchwartz::Job $job = shift;
+    my $job   = shift;
 
     my @args = $job->arg;
 
