@@ -12,7 +12,6 @@ use vars qw/@EXPORT_OK/;
     is_color
     generate_random_word
     get_page_from_url
-    datetime_to_tt2_acceptable
     truncate_text
     be_url_part
     /;
@@ -74,18 +73,6 @@ sub get_page_from_url {
     return $page;
 }
 
-sub datetime_to_tt2_acceptable {
-    my ($datetime) = @_;
-
-    # from MySQL DateTime
-    my ( $YYYY, $MM, $DD, $hour, $minute, $second )
-        = ( $datetime =~ /^(\d+)-0?(\d+)-0?(\d+)\s+0?(\d+)\S+0?(\d+)\S+0?(\d+)$/ );
-
-    # 4:20:36 21/12/2007 TT2 accept this format
-    my $ret = sprintf( "%d:%d:%d %d/%d/%d", $hour, $minute, $second, $DD, $MM, $YYYY );
-    return $ret;
-}
-
 sub truncate_text {
     my ( $text, $len ) = @_;
 
